containertools.replace_n_edge_elements_in_container_with_rests
==============================================================

.. autofunction:: abjad.tools.containertools.replace_n_edge_elements_in_container_with_rests.replace_n_edge_elements_in_container_with_rests
